@@ -74,9 +74,9 @@
 ##
 ## @example
 ## @group
-##    z = [0:0.05:5];
-##    plot3 (cos(2*pi*z), sin(2*pi*z), z, ";helix;");
-##    plot3 (z, exp(2i*pi*z), ";complex sinusoid;");
+## z = [0:0.05:5];
+## plot3 (cos (2*pi*z), sin (2*pi*z), z, ";helix;");
+## plot3 (z, exp (2i*pi*z), ";complex sinusoid;");
 ## @end group
 ## @end example
 ## @seealso{plot, xlabel, ylabel, zlabel, title, print}
@@ -170,6 +170,8 @@ function retval = plot3 (varargin)
 
       if (! size_equal (x, y, z))
         error ("plot3: x, y, and z must have the same shape");
+      elseif (ndims (x) > 2)
+        error ("plot3: x, y, and z must not have more than two dimensions");
       endif
 
       for i = 1 : columns (x)
@@ -222,6 +224,8 @@ function retval = plot3 (varargin)
 
       if (! size_equal (x, y, z))
         error ("plot3: x, y, and z must have the same shape");
+      elseif (ndims (x) > 2)
+        error ("plot3: x, y, and z must not have more than two dimensions");
       endif
 
       options =  __default_plot_options__ ();
@@ -294,6 +298,8 @@ function retval = plot3 (varargin)
 
     if (! size_equal (x, y, z))
       error ("plot3: x, y, and z must have the same shape");
+    elseif (ndims (x) > 2)
+      error ("plot3: x, y, and z must not have more than two dimensions");
     endif
 
     options =  __default_plot_options__ ();
