@@ -1,4 +1,4 @@
-## Copyright (C) 2008-2011 David Bateman
+## Copyright (C) 2008-2012 David Bateman
 ##
 ## This file is part of Octave.
 ##
@@ -18,23 +18,22 @@
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {@var{s} =} spaugment (@var{A}, @var{c})
-## Creates the augmented matrix of @var{A}.  This is given by
+## Create the augmented matrix of @var{A}.  This is given by
 ##
 ## @example
 ## @group
-## [@var{c} * eye(@var{m}, @var{m}),@var{A}; @var{A}', zeros(@var{n},
-## @var{n})]
+## [@var{c} * eye(@var{m}, @var{m}), @var{A};
+##             @var{A}', zeros(@var{n}, @var{n})]
 ## @end group
 ## @end example
 ##
 ## @noindent
 ## This is related to the least squares solution of
-## @code{@var{A} \\ @var{b}}, by
+## @code{@var{A} \ @var{b}}, by
 ##
 ## @example
 ## @group
-## @var{s} * [ @var{r} / @var{c}; x] = [@var{b}, zeros(@var{n},
-## columns(@var{b})]
+## @var{s} * [ @var{r} / @var{c}; x] = [ @var{b}, zeros(@var{n}, columns(@var{b})) ]
 ## @end group
 ## @end example
 ##
@@ -53,7 +52,7 @@
 ##
 ## @example
 ## @group
-## m = 11; n = 10; mn = max(m ,n);
+## m = 11; n = 10; mn = max (m, n);
 ## A = spdiags ([ones(mn,1), 10*ones(mn,1), -ones(mn,1)],
 ##              [-1, 0, 1], m, n);
 ## x0 = A \ ones (m,1);
