@@ -1,11 +1,11 @@
-## Copyright (C) 1995, 1996, 1997  Kurt Hornik
+## Copyright (C) 1995-2012 Kurt Hornik
 ##
 ## This file is part of Octave.
 ##
 ## Octave is free software; you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 2, or (at your option)
-## any later version.
+## the Free Software Foundation; either version 3 of the License, or (at
+## your option) any later version.
 ##
 ## Octave is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,14 +13,13 @@
 ## General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, write to the Free
-## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-## 02110-1301, USA.
+## along with Octave; see the file COPYING.  If not, see
+## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {[@var{pval}, @var{ks}] =} kolmogorov_smirnov_test (@var{x}, @var{dist}, @var{params}, @var{alt})
 ## Perform a Kolmogorov-Smirnov test of the null hypothesis that the
-## sample @var{x} comes from the (continuous) distribution dist. I.e.,
+## sample @var{x} comes from the (continuous) distribution dist.  I.e.,
 ## if F and G are the CDFs corresponding to the sample and dist,
 ## respectively, then the null is that F == G.
 ##
@@ -29,7 +28,7 @@
 ## a uniform distribution on [2,4], use
 ##
 ## @example
-## kolmogorov_smirnov_test(x, "uniform", 2, 4)
+## kolmogorov_smirnov_test(x, "unif", 2, 4)
 ## @end example
 ##
 ## @noindent
@@ -39,7 +38,7 @@
 ## With the optional argument string @var{alt}, the alternative of
 ## interest can be selected.  If @var{alt} is @code{"!="} or
 ## @code{"<>"}, the null is tested against the two-sided alternative F
-## != G.  In this case, the test statistic @var{ks} follows a two-sided
+## != G@.  In this case, the test statistic @var{ks} follows a two-sided
 ## Kolmogorov-Smirnov distribution.  If @var{alt} is @code{">"}, the
 ## one-sided alternative F > G is considered.  Similarly for @code{"<"},
 ## the one-sided alternative F > G is considered.  In this case, the
@@ -61,30 +60,37 @@ function [pval, ks] = kolmogorov_smirnov_test (x, dist, varargin)
   endif
 
   if (! isvector (x))
-    error ("kolmogorov_smirnov_test: x must be a vector");
+    error ("kolmogorov_smirnov_test: X must be a vector");
   endif
 
   n = length (x);
   s = sort (x);
-  f = str2func (sprintf ("%s_cdf", dist));
+  try
+    f = str2func (sprintf ("%scdf", dist));
+  catch
+    try
+      f = str2func (sprintf ("%s_cdf", dist));
+    catch
+      error ("kolmogorov_smirnov_test: no %scdf or %s_cdf function found",
+             dist, dist);
+    end_try_catch
+  end_try_catch
 
   alt  = "!=";
 
-  if (nargin == 2)
-    z = reshape (feval (f, s), 1, n);
-  else
-    args = "";
-    for k = 1 : (nargin-2);
-      tmp  = varargin{k};
-      if ischar (tmp)
-        alt = tmp;
-      else
-        args = sprintf ("%s, %g", args, tmp);
-      endif
-    endfor
-    z = reshape (eval (sprintf ("%s(s%s);", func2str (f), args)), 1, n);
+  args{1} = s;
+  nvargs = numel (varargin);
+  if (nvargs > 0)
+    if (ischar (varargin{end}))
+      alt = varargin{end};
+      args(2:nvargs) = varargin(1:end-1);
+    else
+      args(2:nvargs+1) = varargin;
+    endif
   endif
 
+  z = reshape (feval (f, args{:}), 1, n);
+
   if (strcmp (alt, "!=") || strcmp (alt, "<>"))
     ks   = sqrt (n) * max (max ([abs(z - (0:(n-1))/n); abs(z - (1:n)/n)]));
     pval = 1 - kolmogorov_smirnov_cdf (ks);
@@ -103,3 +109,18 @@ function [pval, ks] = kolmogorov_smirnov_test (x, dist, varargin)
   endif
 
 endfunction
+
+%!error <Invalid call to kolmogorov_smirnov_test>
+%!  kolmogorov_smirnov_test (1);
+%!error <kolmogorov_smirnov_test: X must be a vector>
+%!  kolmogorov_smirnov_test ({}, "unif", 2, 4);
+%!error <kolmogorov_smirnov_test: no not_a_distcdf or not_a_dist_cdf function found>
+%!  kolmogorov_smirnov_test (1, "not_a_dist");
+%!error <kolmogorov_smirnov_test: alternative bla not recognized>
+%!  kolmogorov_smirnov_test (1, "unif", 2, 4, "bla");
+%!test # for recognition of unifcdf function
+%!  assert (kolmogorov_smirnov_test (0:100, "unif", 0, 100), 1.0, eps);
+%!test # for recognition of logistic_cdf function
+%!  assert (kolmogorov_smirnov_test (0:100, "logistic"), 0);
+%!test # F < G
+%!  assert (kolmogorov_smirnov_test (50:100, "unif", 0, 50, "<"));
